@@ -113,6 +113,12 @@ Q_SIGNALS:
      * Request a pointer motion by @p delta.
      **/
     void pointerMotionRequested(const QSizeF &delta);
+    /**
+     * Request an absolute pointer motion to @p pos.
+     *
+     * @since 5.54
+     **/
+    void pointerMotionAbsoluteRequested(const QPointF &pos);
     /**
      * Requests a pointer button pressed for @p button.
      **/
@@ -125,6 +131,36 @@ Q_SIGNALS:
      * Requests a pointer axis for the given @p orientation by @p delta.
      **/
     void pointerAxisRequested(Qt::Orientation orientation, qreal delta);
+    /**
+     * Requests a touch down at @p pos and identified by @p id.
+     *
+     * @since 5.23
+     **/
+    void touchDownRequested(quint32 id, const QPointF &pos);
+    /**
+     * Requests a touch motion by @p pos and identified by @p id.
+     *
+     * @since 5.23
+     **/
+    void touchMotionRequested(quint32 id, const QPointF &pos);
+    /**
+     * Requests a touch up identified by @p id.
+     *
+     * @since 5.23
+     **/
+    void touchUpRequested(quint32 id);
+    /**
+     * Requests a touch cancel event.
+     *
+     * @since 5.23
+     **/
+    void touchCancelRequested();
+    /**
+     * Requests a touch frame event.
+     *
+     * @since 5.23
+     **/
+    void touchFrameRequested();
 
 private:
     friend class FakeInputInterface;
