@@ -36,9 +36,13 @@ namespace Server
 class BlurManagerInterface;
 class BlurInterface;
 class BufferInterface;
+class ConfinedPointerInterface;
 class ContrastInterface;
 class ContrastManagerInterface;
 class CompositorInterface;
+class IdleInhibitManagerUnstableV1Interface;
+class LockedPointerInterface;
+class PointerConstraintsUnstableV1Interface;
 class ShadowManagerInterface;
 class ShadowInterface;
 class SlideInterface;
@@ -114,7 +118,9 @@ public:
     BufferInterface *buffer();
     QPoint offset() const;
     /**
-     * The size of the Surface.
+     * The size of the Surface in global compositor space.
+     * @see For buffer size use BufferInterface::size
+     * from SurfaceInterface::buffer
      * @since 5.3
      **/
     QSize size() const;
@@ -164,16 +170,16 @@ public:
     bool isMapped() const;
 
     /**
-     * Returns the tracked damage since the last call to @link resetTrackedDamage.
-     * In contrast to @link damage this method does not reset the damage when
+     * Returns the tracked damage since the last call to  {@link resetTrackedDamage}.
+     * In contrast to {@link damage} this method does not reset the damage when
      * a new BufferInterface gets committed. This allows a compositor to properly
      * track the damage over multiple commits even if it didn't render each new
      * BufferInterface.
      *
-     * The damage gets reset whenever @link resetTrackedDamage is called.
+     * The damage gets reset whenever {@link resetTrackedDamage} is called.
      * This allows a compositor to properly track the change in its rendering scene
      * for this SurfaceInterface. After it updates its internal state (e.g. by creating
-     * an OpenGL texture from the BufferInterface) it can invoke @link resetTrackedDamage
+     * an OpenGL texture from the BufferInterface) it can invoke {@link resetTrackedDamage}
      * and the damage tracker will start to track further damage changes.
      *
      * @returns Combined damage since last call to resetTrackedDamage
@@ -205,6 +211,21 @@ public:
      **/
     SurfaceInterface *surfaceAt(const QPointF &position);
 
+    /**
+     * Finds the input receiving SurfaceInterface at the given @p position in surface-local coordinates.
+     * This can be either a descendant SurfaceInterface honoring the stacking order or
+     * the SurfaceInterface itself if its geometry contains the given @p position.
+     *
+     * If no such SurfaceInterface is found, e.g. because the SurfaceInterface is unmapped or there is no
+     * input region containing the position,
+     * @c nullptr is returned.
+     *
+     * @param position The position in surface-local coordinates
+     * @returns Input receiving child surface at the given @p position or surface itself at the position, might be @c nullptr
+     * @since 5.52
+     **/
+    SurfaceInterface *inputSurfaceAt(const QPointF &position);
+
     /**
      * Sets the @p outputs this SurfaceInterface overlaps with, may be empty.
      *
@@ -223,6 +244,27 @@ public:
      **/
     QVector<OutputInterface *> outputs() const;
 
+    /**
+     * Pointer confinement installed on this SurfaceInterface.
+     * @see pointerConstraintsChanged
+     * @since 5.29
+     **/
+    QPointer<ConfinedPointerInterface> confinedPointer() const;
+
+    /**
+     * Pointer lock installed on this SurfaceInterface.
+     * @see pointerConstraintsChanged
+     * @since 5.29
+     **/
+    QPointer<LockedPointerInterface> lockedPointer() const;
+
+    /**
+     * @returns Whether this SurfaceInterface wants idle to be inhibited on the Output it is shown
+     * @see inhibitsIdleChanged
+     * @since 5.41
+     **/
+    bool inhibitsIdle() const;
+
     /**
      * @returns The SurfaceInterface for the @p native resource.
      **/
@@ -233,6 +275,22 @@ public:
      **/
     static SurfaceInterface *get(quint32 id, const ClientConnection *client);
 
+    /**
+     * Set @p surface as a data proxy for this SurfaceInterface. This enables
+     * the proxy to conduct drags on the surface's client behalf.
+     *
+     * Setting a data proxy is only allowed when the client owning this surface
+     * has not created a data device itself.
+     * @since 5.56
+     **/
+    void setDataProxy(SurfaceInterface *surface);
+    /**
+     * Returns the data proxy of this SurfaceInterface or null if there
+     * is none set.
+     * @since 5.56
+     **/
+    SurfaceInterface* dataProxy() const;
+
 Q_SIGNALS:
     /**
      * Emitted whenever the SurfaceInterface got damaged.
@@ -277,6 +335,34 @@ Q_SIGNALS:
      **/
     void subSurfaceTreeChanged();
 
+    /**
+     * Emitted whenever a pointer constraint get (un)installed on this SurfaceInterface.
+     *
+     * The pointer constraint does not get activated, the compositor needs to activate
+     * the lock/confinement.
+     *
+     * @see confinedPointer
+     * @see lockedPointer
+     * @since 5.29
+     **/
+    void pointerConstraintsChanged();
+
+    /**
+     * Emitted whenever the SurfaceInterface starts/ends to inhibit idle.
+     * @see inhibitsIdle
+     * @since 5.41
+     **/
+    void inhibitsIdleChanged();
+
+    /**
+     * Emitted when the Surface has been committed.
+     *
+     * This signal is emitted after all the relevant damage and xyzChanged signals
+     * for this commit are emitted.
+     * @since 5.54
+     **/
+    void committed();
+
 private:
     friend class CompositorInterface;
     friend class SubSurfaceInterface;
@@ -284,6 +370,8 @@ private:
     friend class BlurManagerInterface;
     friend class SlideManagerInterface;
     friend class ContrastManagerInterface;
+    friend class IdleInhibitManagerUnstableV1Interface;
+    friend class PointerConstraintsUnstableV1Interface;
     explicit SurfaceInterface(CompositorInterface *parent, wl_resource *parentResource);
 
     class Private;
